part of pdf;

/// Represents the base class for annotation objects.
abstract class PdfAnnotation implements _IPdfWrapper {
  // constructor
  PdfAnnotation._({PdfPage page, String text, Rect bounds}) {
    _initialize();
    if (page != null) {
      _page = page;
    }
    if (bounds != null) {
      this.bounds = bounds;
    }
    if (text != null) {
      this.text = text ??= _text;
      _dictionary.setProperty(
          _PdfName(_DictionaryProperties.contents), _PdfString(text));
    }
  }

  // fields
  PdfPage _page;
  String _text = '';
  final _PdfDictionary _dictionary = _PdfDictionary();
  _Rectangle _rectangle;
  PdfColor _innerColor;
  PdfAnnotationBorder _border;

  // properties
  /// Gets a page of the annotation. Read-Only.
  PdfPage get page => _page;

  /// Gets annotation's bounds in the PDF page.
  Rect get bounds => _rectangle.rect;

  /// Sets annotation's bounds in the PDF page.
  set bounds(Rect value) {
    ArgumentError.checkNotNull(value);
    final _Rectangle rectangle = _Rectangle.fromRect(value);
    if (_rectangle != rectangle) {
      _rectangle = rectangle;
      _dictionary.setProperty(_PdfName(_DictionaryProperties.rect),
          _PdfArray.fromRectangle(rectangle));
    }
  }

  /// Gets annotation's border properties like width, horizontal radius etc.
  PdfAnnotationBorder get border {
    _border ??= PdfAnnotationBorder();
    return _border;
  }

  /// Sets annotation's border properties like width, horizontal radius etc.
  set border(PdfAnnotationBorder value) {
    _border = value;
    _dictionary.setProperty(
        _PdfName(_DictionaryProperties.border), _border._element);
  }

  /// Gets content of the annotation.The string value specifies the text of the annotation.
  String get text {
    if (_dictionary.containsKey(_DictionaryProperties.contents)) {
      _text = (_dictionary[_DictionaryProperties.contents] as _PdfString).value;
    }
    return _text;
  }

  /// Sets content of the annotation.The string value specifies the text of the annotation.
  set text(String value) {
    ArgumentError.checkNotNull(value, 'text');
    if (_text != value) {
      _text = value;
      _dictionary._setString(_DictionaryProperties.contents, _text);
    }
  }

  // implementation
  void _initialize() {
    _dictionary._beginSave = _dictionaryBeginSave;
    _dictionary.setProperty(_PdfName(_DictionaryProperties.type),
        _PdfName(_DictionaryProperties.annot));
    _innerColor = PdfColor(0, 0, 0, 0);
  }

  void _dictionaryBeginSave(Object sender, _SavePdfPrimitiveArgs ars) {
    if (_isContainsAnnotation()) {
      _save();
    }
  }

  bool _isContainsAnnotation() {
    bool contains = false;
    _PdfArray annotation;
    if (page != null &&
        page._dictionary.containsKey(_DictionaryProperties.annots)) {
      annotation = _PdfCrossTable._dereference(
          page._dictionary[_DictionaryProperties.annots]) as _PdfArray;
      if (annotation != null && annotation._contains(annotation._elements[0])) {
        contains = true;
      }
    }
    return contains;
  }

  void _save() {
    if (border != null) {
      _dictionary.setProperty(
          _PdfName(_DictionaryProperties.border), border._element);
    }
    final _Rectangle nativeRectangle = _obtainNativeRectangle();
    if (_innerColor != null &&
        !_innerColor.isEmpty &&
        _innerColor._alpha != 0.0)
      _dictionary.setProperty(
          _PdfName(_DictionaryProperties.ic), _innerColor._toArray());
    _dictionary.setProperty(_PdfName(_DictionaryProperties.rect),
        _PdfArray.fromRectangle(nativeRectangle));
  }

  _Rectangle _obtainNativeRectangle() {
    final _Rectangle nativeRectangle =
        _Rectangle(bounds.left, bounds.bottom, bounds.width, bounds.height);
    _PdfArray cropOrMediaBox;
    if (_page != null) {
      final PdfSection section = _page._section;

      nativeRectangle.location =
          section._pointToNativePdf(page, nativeRectangle.location);

      cropOrMediaBox = _getCropOrMediaBox(_page, cropOrMediaBox);
    }
    if (cropOrMediaBox != null) {
      if (cropOrMediaBox.count > 2 &&
          cropOrMediaBox[0] != null &&
          cropOrMediaBox[1] != null) {
        if ((cropOrMediaBox[0] as _PdfNumber).value != 0 ||
            (cropOrMediaBox[1] as _PdfNumber).value != 0) {
          nativeRectangle.x =
              nativeRectangle.x + (cropOrMediaBox[0] as _PdfNumber).value;
          nativeRectangle.y =
              nativeRectangle.y + (cropOrMediaBox[1] as _PdfNumber).value;
        }
      }
    }
    return nativeRectangle;
  }

  _PdfArray _getCropOrMediaBox(PdfPage page, _PdfArray cropOrMediaBox) {
    if (page._dictionary.containsKey(_DictionaryProperties.cropBox)) {
      cropOrMediaBox = _PdfCrossTable._dereference(
          page._dictionary[_DictionaryProperties.cropBox]) as _PdfArray;
    } else if (page._dictionary.containsKey(_DictionaryProperties.mediaBox)) {
      cropOrMediaBox = _PdfCrossTable._dereference(
          page._dictionary[_DictionaryProperties.mediaBox]) as _PdfArray;
    }
    return cropOrMediaBox;
  }

  void _setPage(PdfPage page) {
    if (page is PdfPage) {
      _page = page;
      final PdfGraphics graphics = page.graphics;
      ArgumentError.checkNotNull(graphics, 'graphics');
      if (_dictionary.containsKey(_DictionaryProperties.subtype)) {
        final _PdfName name = _dictionary
            ._items[_PdfName(_DictionaryProperties.subtype)] as _PdfName;
        if (name != null) {
          if (name._name == _DictionaryProperties.text) {
            _page._document._catalog._beginSave = _dictionaryBeginSave;
            _page._document._catalog.modify();
          }
        }
      }
    }
    if (_page != null) {
      _dictionary.setProperty(
          _PdfName(_DictionaryProperties.p), _PdfReferenceHolder(_page));
    }
  }
}
