part of pdf;

/// Each instance of this class represents an bookmark node in the bookmark tree.
class PdfBookmark extends PdfBookmarkBase {
  /// Initializes a new instance of the [PdfBookmark] class.
  PdfBookmark._internal(String title, PdfBookmarkBase parent,
      PdfBookmark previous, PdfBookmark next)
      : super._internal() {
    ArgumentError.checkNotNull(parent, 'parent');
    ArgumentError.checkNotNull(title, 'title');
    _parent = parent;
    _previous = previous;
    _next = next;
    this.title = title;
  }

  /// Internal variable to store destination.
  PdfDestination _destination;

  /// Internal variable to store named destination.
  PdfNamedDestination _namedDestination;

  /// Internal variable to store text Style.
  List<PdfTextStyle> _textStyle = <PdfTextStyle>[PdfTextStyle.regular];

  /// Internal variable to store previous.
  PdfBookmark _previousBookmark;

  /// Internal variable to store next.
  PdfBookmark _nextBookmark;

  /// Internal variable to store parent.
  PdfBookmarkBase _parent;

  /// Internal variable to store color.
  PdfColor _color;

  /// Internal variable to store action.
  PdfAction _action;

  /// Gets the outline destination page.
  PdfDestination get destination => _destination;

  /// Sets the outline destination page.
  set destination(PdfDestination value) {
    ArgumentError.checkNotNull(value, 'destination');
    _destination = value;
    _dictionary.setProperty(_DictionaryProperties.dest, value);
  }

  /// Gets the named destination in outline.
  PdfNamedDestination get namedDestination => _namedDestination;

  /// Sets the named destination in outline.
  set namedDestination(PdfNamedDestination value) {
    if (_namedDestination != value) {
      _namedDestination = value;
      final _PdfDictionary dictionary = _PdfDictionary();
      dictionary.setProperty(
          _DictionaryProperties.d, _PdfString(_namedDestination.title));
      dictionary.setProperty(
          _DictionaryProperties.s, _PdfName(_DictionaryProperties.goTo));
      _dictionary.setProperty(
          _DictionaryProperties.a, _PdfReferenceHolder(dictionary));
    }
  }

  /// Gets the outline title.
  String get title {
    final _PdfString title =
        _dictionary[_DictionaryProperties.title] as _PdfString;
    return title != null ? title.value : null;
  }

  /// Sets the outline title.
  set title(String value) {
    ArgumentError.checkNotNull(value, 'title');
    _dictionary[_DictionaryProperties.title] = _PdfString(value);
  }

  /// Gets the color of bookmark title.
  PdfColor get color => _color;

  /// Sets the color of bookmark title.
  set color(PdfColor value) {
    if (_color != value) {
      _color = value;
      _updateColor();
    }
  }

  /// Gets the style of the outline title.
  List<PdfTextStyle> get textStyle => _textStyle;

  /// Sets the style of the outline title.
  set textStyle(List<PdfTextStyle> value) {
    ArgumentError.checkNotNull(value, 'textStyle');
    if (_textStyle != value) {
      _textStyle = value;
      _updateTextStyle();
    }
  }

  /// Gets the action for the outline.
  PdfAction get action => _action;

  // Sets the action for the outline.
  set action(PdfAction value) {
    if (_action != value) {
      _action = value;
      _dictionary.setProperty(
          _DictionaryProperties.a, _PdfReferenceHolder(_action._dictionary));
    }
  }

  PdfBookmark get _previous => _previousBookmark;

  set _previous(PdfBookmark value) {
    if (_previousBookmark != value) {
      _previousBookmark = value;
      _dictionary.setProperty(
          _DictionaryProperties.prev, _PdfReferenceHolder(value));
    }
  }

  /// Gets the next outline object.
  PdfBookmark get _next => _nextBookmark;

  /// Sets the next outline object.
  set _next(PdfBookmark value) {
    if (_nextBookmark != value) {
      _nextBookmark = value;
      _dictionary.setProperty(
          _DictionaryProperties.next, _PdfReferenceHolder(value));
    }
  }

  /// Gets whether to expand the node or not.
  bool get isExpanded => super._isExpanded;

  /// Sets whether to expand the node or not.
  set isExpanded(bool value) {
    super._isExpanded = value;
  }

  void _updateColor() {
    final _PdfArray array = _dictionary[_DictionaryProperties.c] as _PdfArray;
    if (array != null && _color.isEmpty) {
      _dictionary.remove(_DictionaryProperties.c);
    } else {
      _dictionary[_DictionaryProperties.c] = _color._toArray(PdfColorSpace.rgb);
    }
  }

  /// Updates the outline text style.
  void _updateTextStyle() {
    if (_textStyle.length == 1 && _textStyle[0] == PdfTextStyle.regular)
      _dictionary.remove(_DictionaryProperties.f);
    else {
      int value = 0;
      for (int i = 0; i < _textStyle.length; i++) {
        value |= _textStyle[i].index;
      }
      _dictionary[_DictionaryProperties.f] = _PdfNumber(value);
    }
  }
}
