part of pdf;

/// Represents a PDF document and can be used to create a new PDF document from the scratch
class PdfDocument {
  //Constructor
  /// Initialize a new instance of the [PdfDocument] class.
  /// ```dart
  /// //Create a new PDF document.
  /// PdfDocument document = PdfDocument();
  /// //Add a PDF page and draw text.
  /// document.pages.add().graphics.drawString(
  ///     'Hello World!', PdfStandardFont(PdfFontFamily.helvetica, 12),
  ///     brush: PdfSolidBrush(PdfColor(0, 0, 0)),
  ///     bounds: Rect.fromLTWH(0, 0, 150, 20));
  /// //Save the document.
  /// List<int> bytes = document.save();
  /// //Dispose the document.
  /// document.dispose();
  /// ```
  PdfDocument() {
    _objects = _PdfMainObjectCollection();
    _crossTable = _PdfCrossTable();
    _crossTable._document = this;
    _catalog = _PdfCatalog();
    _objects._add(_catalog);
    _catalog.position = -1;
    _sections = PdfSectionCollection._(this);
    _pages = PdfPageCollection._(this);
    _catalog._pages = _sections;
    compressionLevel = PdfCompressionLevel.normal;
  }

  //Constants
  static const double _defaultMargin = 40;

  //Fields
  _PdfMainObjectCollection _objects;
  _PdfCrossTable _crossTable;
  _PdfCatalog _catalog;
  PdfPageCollection _pages;
  PdfPageSettings _settings;
  PdfSectionCollection _sections;
  PdfFileStructure _fileStructure;
  PdfCompressionLevel compressionLevel;
  PdfColorSpace _colorSpace;
  PdfDocumentTemplate _template;
  PdfBookmarkBase _outlines;
  PdfNamedDestinationCollection _namedDestinations;

  //Properties
  /// Gets the collection of the sections in the document.
  ///
  /// ```dart
  /// //Create a PDF document instance.
  /// PdfDocument document = PdfDocument();
  /// //Add a new section.
  /// PdfSection section = document.sections.add();
  /// //Create page for the newly added section and draw text.
  /// section.pages.add().graphics.drawString(
  ///     'Hello World!', PdfStandardFont(PdfFontFamily.helvetica, 12),
  ///      brush: PdfBrushes.black, bounds: Rect.fromLTWH(0, 0, 0, 0));
  /// //Save and dispose document.
  /// List<int> bytes = document.save();
  /// document.dispose();
  /// ```
  PdfSectionCollection get sections => _sections;

  /// Gets the document's page setting.
  ///
  /// ```dart
  /// //Create a PDF document instance.
  /// PdfDocument document = PdfDocument();
  /// //Get the document page settings.
  /// document.pageSettings.margins.all = 50;
  /// //Create page and draw text.
  /// document.pages.add().graphics.drawString(
  ///     'Hello World!', PdfStandardFont(PdfFontFamily.helvetica, 12),
  ///     brush: PdfBrushes.black, bounds: Rect.fromLTWH(0, 0, 0, 0));
  /// //Save and dispose document.
  /// List<int> bytes = document.save();
  /// document.dispose();
  /// ```
  PdfPageSettings get pageSettings {
    if (_settings == null) {
      _settings = PdfPageSettings();
      _settings.setMargins(_defaultMargin);
    }
    return _settings;
  }

  /// Sets the document's page setting.
  ///
  /// ```dart
  /// //Create a PDF document instance.
  /// PdfDocument document = PdfDocument();
  /// //Create a PDF page settings.
  /// PdfPageSettings settings = PdfPageSettings();
  /// settings.margins.all = 50;
  /// //Set the page settings to document.
  /// document.pageSettings = settings;
  /// //Create page and draw text.
  /// document.pages.add().graphics.drawString(
  ///     'Hello World!', PdfStandardFont(PdfFontFamily.helvetica, 12),
  ///     brush: PdfBrushes.black, bounds: Rect.fromLTWH(0, 0, 0, 0));
  /// //Save and dispose document.
  /// List<int> bytes = document.save();
  /// document.dispose();
  /// ```
  set pageSettings(PdfPageSettings settings) {
    if (settings == null) {
      throw ArgumentError.notNull('settings');
    } else {
      _settings = settings;
    }
  }

  /// Gets a template to all pages in the document.
  PdfDocumentTemplate get template {
    _template ??= PdfDocumentTemplate();
    return _template;
  }

  /// Sets a template to all pages in the document.
  set template(PdfDocumentTemplate value) {
    _template = value;
  }

  /// Gets the color space of the document. This property can be used to create PDF document in RGB, Grayscale or CMYK color spaces.
  ///
  /// By default the document uses RGB color space.
  PdfColorSpace get colorSpace {
    if ((_colorSpace == PdfColorSpace.rgb) ||
        ((_colorSpace == PdfColorSpace.cmyk) ||
            (_colorSpace == PdfColorSpace.grayScale))) {
      return _colorSpace;
    } else {
      return PdfColorSpace.rgb;
    }
  }

  /// Sets the color space of the document. This property can be used to create PDF document in RGB, Grayscale or CMYK color spaces.
  ///
  /// By default the document uses RGB color space.
  set colorSpace(PdfColorSpace value) {
    if ((value == PdfColorSpace.rgb) ||
        ((value == PdfColorSpace.cmyk) || (value == PdfColorSpace.grayScale))) {
      _colorSpace = value;
    } else {
      _colorSpace = PdfColorSpace.rgb;
    }
  }

  /// Gets the internal structure of the PDF document.
  PdfFileStructure get fileStructure {
    _fileStructure ??= PdfFileStructure();
    return _fileStructure;
  }

  /// Sets the internal structure of the PDF document.
  set fileStructure(PdfFileStructure value) {
    _fileStructure = value;
  }

  /// Gets the collection of pages in the document.
  ///
  /// ```dart
  /// //Create a PDF document instance.
  /// PdfDocument document = PdfDocument();
  /// //Get the page and draw text.
  /// document.pages.add().graphics.drawString(
  ///     'Hello World!', PdfStandardFont(PdfFontFamily.helvetica, 12),
  ///     brush: PdfBrushes.black, bounds: Rect.fromLTWH(0, 0, 0, 0));
  /// //Save and dispose document.
  /// List<int> bytes = document.save();
  /// document.dispose();
  /// ```
  PdfPageCollection get pages => _getPageCollection();

  /// Gets the bookmark collection of the document.
  PdfBookmarkBase get bookmarks {
    if (_outlines == null) {
      _outlines = PdfBookmarkBase._internal();
      _catalog[_DictionaryProperties.outlines] = _PdfReferenceHolder(_outlines);
    }
    return _outlines;
  }

  /// Gets the named destination collection of the document.
  PdfNamedDestinationCollection get namedDestinationCollection {
    if (_namedDestinations == null) {
      _namedDestinations = PdfNamedDestinationCollection();
      _catalog[_DictionaryProperties.names] =
          _PdfReferenceHolder(_namedDestinations);
      final _PdfReferenceHolder names =
          _catalog[_DictionaryProperties.names] as _PdfReferenceHolder;
      if (names != null) {
        final _PdfDictionary dic = names.object as _PdfDictionary;
        if (dic != null)
          dic[_DictionaryProperties.dests] =
              _PdfReferenceHolder(_namedDestinations);
      }
    }
    return _namedDestinations;
  }

  //Public methods
  /// Saves the document and return the saved bytes as list of int.
  ///
  /// ```dart
  /// //Create a PDF document instance.
  /// PdfDocument document = PdfDocument();
  /// //Get the page and draw text.
  /// document.pages.add().graphics.drawString(
  ///     'Hello World!', PdfStandardFont(PdfFontFamily.helvetica, 12),
  ///     brush: PdfBrushes.black, bounds: Rect.fromLTWH(0, 0, 0, 0));
  /// //Save and dispose document.
  /// List<int> bytes = document.save();
  /// document.dispose();
  /// ```
  List<int> save() {
    if (pages.count == 0) {
      pages.add();
    }
    if (!_checkLicense()) {
      _addWaterMark();
    }
    final List<int> buffer = <int>[];
    final _PdfWriter writer = _PdfWriter(buffer);
    writer._document = this;
    _crossTable._save(writer);
    return writer._buffer;
  }

  bool _checkLicense() {
    final String result = SyncfusionLicense.validateLicense();
    return result == null ? true : false;
  }

  void _addWaterMark() {
    if (pages != null && pages.count > 0 && pages[0] != null) {
      final PdfPage page = pages[0];
      final PdfPageRotateAngle angle = pageSettings.rotate;
      PdfTemplate template;
      if (angle == PdfPageRotateAngle.rotateAngle0 ||
          angle == PdfPageRotateAngle.rotateAngle90 ||
          angle == PdfPageRotateAngle.rotateAngle270) {
        template = PdfTemplate(page.size.width, page.size.height);
      } else if (angle == PdfPageRotateAngle.rotateAngle180) {
        template = PdfTemplate(page.size.width, 33.75);
      }
      template.graphics.save();
      template.graphics.setTransparency(0.20);
      if (angle == PdfPageRotateAngle.rotateAngle0 ||
          angle == PdfPageRotateAngle.rotateAngle180)
        template.graphics.drawRectangle(
            brush: PdfBrushes.white,
            bounds: Rect.fromLTWH(0, 0, page.size.width, 33.75));
      else if (angle == PdfPageRotateAngle.rotateAngle90) {
        template.graphics.drawRectangle(
            brush: PdfBrushes.white,
            bounds: Rect.fromLTWH(0, 0, 33.75, page.size.height));
      } else {
        template.graphics.drawRectangle(
            brush: PdfBrushes.white,
            bounds: Rect.fromLTWH(
                page.size.width - 33.75, 0, 33.75, page.size.height));
      }
      const String waterMarkText =
          'Created with a trial version of Syncfusion Essential PDF';
      template.graphics.restore();
      template.graphics.save();
      template.graphics.setTransparency(0.50);
      final PdfStandardFont font = PdfStandardFont(PdfFontFamily.helvetica, 12);
      final _Size textSize = _Size(220.962, 16.184);
      final PdfStringFormat format = PdfStringFormat(
          alignment: PdfTextAlignment.center,
          lineAlignment: PdfVerticalAlignment.middle);

      if (angle == PdfPageRotateAngle.rotateAngle180) {
        template.graphics.translateTransform(page.size.width, 0);
        template.graphics.rotateTransform(180);
        template.graphics.drawString(waterMarkText, font,
            brush: PdfBrushes.black,
            bounds: Rect.fromLTWH(
                page.size.width / 2 - textSize.width / 2, -22, 0, 0));
      } else if (angle == PdfPageRotateAngle.rotateAngle90) {
        template.graphics.translateTransform(0, page.size.height);
        template.graphics.rotateTransform(-90);
        template.graphics.drawString(waterMarkText, font,
            brush: PdfBrushes.black,
            bounds: Rect.fromLTWH(0, 0, page.size.height, 33.75),
            format: format);
      } else if (angle == PdfPageRotateAngle.rotateAngle270) {
        template.graphics.translateTransform(page.size.width - 33.75, 0);
        template.graphics.rotateTransform(90);
        template.graphics.drawString(waterMarkText, font,
            brush: PdfBrushes.black,
            bounds: Rect.fromLTWH(
                page.size.height / 2 - textSize.width / 2, -22, 0, 0));
      } else
        template.graphics.drawString(waterMarkText, font,
            brush: PdfBrushes.black,
            bounds: Rect.fromLTWH(0, 0, page.size.width, 33.75),
            format: format);
      template.graphics.restore();
      _setWaterMarkResources(template._resources, page._getResources());
      final _PdfDictionary dictionary = template._content;
      dictionary._items.clear();
      final _PdfReferenceHolder refHolder =
          _PdfReferenceHolder(dictionary as _PdfStream);
      page._contents._add(refHolder);
    }
  }

  void _setWaterMarkResources(
      _PdfResources templateResources, _PdfResources pageResources) {
    final _PdfName extName = _PdfName(_DictionaryProperties.extGState);
    final _PdfName fontName = _PdfName(_DictionaryProperties.font);
    if (templateResources.containsKey(extName)) {
      final _PdfDictionary extGState =
          templateResources._items[extName] as _PdfDictionary;
      if (pageResources._items.containsKey(extName)) {
        final _PdfDictionary ext =
            pageResources._items[extName] as _PdfDictionary;
        if (ext != null) {
          extGState._items.forEach((_PdfName key, _IPdfPrimitive value) {
            if (!ext._items.containsKey(key)) {
              ext._items[key] = value;
            }
          });
        }
      } else {
        pageResources._items[extName] = extGState;
      }
    }
    if (templateResources.containsKey(fontName)) {
      final _PdfDictionary fontDictonary = templateResources
          ._items[_PdfName(_DictionaryProperties.font)] as _PdfDictionary;
      if (pageResources._items.containsKey(fontName)) {
        final _PdfDictionary fontDic =
            pageResources._items[fontName] as _PdfDictionary;
        if (fontDic != null) {
          fontDictonary._items.forEach((_PdfName key, _IPdfPrimitive value) {
            if (!fontDic._items.containsKey(key)) {
              fontDic._items[key] = value;
            } else {
              fontDic._items[
                  _PdfName(_PdfResources._globallyUniqueIdentifier)] = value;
            }
          });
        }
      } else {
        pageResources._items[fontName] = fontDictonary;
      }
    }
  }

  /// Releases all the resources used by document instances.
  ///
  /// ```dart
  /// //Create a PDF document instance.
  /// PdfDocument document = PdfDocument();
  /// //Get the page and draw text.
  /// document.pages.add().graphics.drawString(
  ///     'Hello World!', PdfStandardFont(PdfFontFamily.helvetica, 12),
  ///     brush: PdfBrushes.black, bounds: Rect.fromLTWH(0, 0, 0, 0));
  /// //Save and dispose document.
  /// List<int> bytes = document.save();
  /// document.dispose();
  /// ```
  void dispose() {
    PdfBrushes._dispose();
    PdfPens._dispose();
    if (_crossTable != null) {
      _crossTable._dispose();
    }
  }

  //Implementation
  PdfPageCollection _getPageCollection() {
    _pages ??= PdfPageCollection._(this);
    return _pages;
  }
}
